@@ -2,7 +2,7 @@ package DBIx::QuickORM::Role::Row;
 use strict;
 use warnings;
 
-our $VERSION = '0.000016';
+our $VERSION = '0.000017';
 
 use Carp qw/croak/;
 use List::Util qw/zip/;
@@ -45,6 +45,13 @@ sub display {
     return $source->source_orm_name . "(" . join(', ' => $self->primary_key_value_list) . ")";
 }
 
+sub conflate_args {
+    my $self = shift;
+    my ($field, $val) = @_;
+
+    return (field => $field, value => $val, source => $self->source, dialect => $self->dialect, affinity => $self->field_affinity($field));
+}
+
 #####################
 # {{{ Sanity Checks #
 #####################
